==> 1.2.2.tar.gz: lib/model/apple_verify_receipt_request.dart <==
part of forestvpn_api.api;

class AppleVerifyReceiptRequest {
  /* The latest Base64-encoded transaction receipt. */
  String receipt = null;
  
  Map<String, String> analyticIds = {};
  
  String advId = null;
  AppleVerifyReceiptRequest();

  @override
  String toString() {
    return 'AppleVerifyReceiptRequest[receipt=$receipt, analyticIds=$analyticIds, advId=$advId, ]';
  }

  AppleVerifyReceiptRequest.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    receipt = json['receipt'];
    analyticIds = (json['analytic_ids'] == null) ?
      null :
      (json['analytic_ids'] as Map).cast<String, String>();
    advId = json['adv_id'];
  }

  Map<String, dynamic> toJson() {
    Map <String, dynamic> json = {};
    if (receipt != null)
      json['receipt'] = receipt;
    if (analyticIds != null)
      json['analytic_ids'] = analyticIds;
    if (advId != null)
      json['adv_id'] = advId;
    return json;
  }

  static List<AppleVerifyReceiptRequest> listFromJson(List<dynamic> json) {
    return json == null ? List<AppleVerifyReceiptRequest>() : json.map((value) => AppleVerifyReceiptRequest.fromJson(value)).toList();
  }

  static Map<String, AppleVerifyReceiptRequest> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, AppleVerifyReceiptRequest>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) => map[key] = AppleVerifyReceiptRequest.fromJson(value));
    }
    return map;
  }

  // maps a json object with a list of AppleVerifyReceiptRequest-objects as value to a dart map
  static Map<String, List<AppleVerifyReceiptRequest>> mapListFromJson(Map<String, dynamic> json) {
    var map = Map<String, List<AppleVerifyReceiptRequest>>();
     if (json != null && json.isNotEmpty) {
       json.forEach((String key, dynamic value) {
         map[key] = AppleVerifyReceiptRequest.listFromJson(value);
       });
     }
     return map;
  }
}

==> 1.2.3.tar.gz: lib/model/apple_verify_receipt_request.dart <==
part of forestvpn_api.api;

class AppleVerifyReceiptRequest {
  /* The latest Base64-encoded transaction receipt. */
  String receipt = null;
  
  int price = null;
  
  String currency = null;
  
  Map<String, String> analyticIds = {};
  
  String advId = null;
  AppleVerifyReceiptRequest();

  @override
  String toString() {
    return 'AppleVerifyReceiptRequest[receipt=$receipt, price=$price, currency=$currency, analyticIds=$analyticIds, advId=$advId, ]';
  }

  AppleVerifyReceiptRequest.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    receipt = json['receipt'];
    price = json['price'];
    currency = json['currency'];
    analyticIds = (json['analytic_ids'] == null) ?
      null :
      (json['analytic_ids'] as Map).cast<String, String>();
    advId = json['adv_id'];
  }

  Map<String, dynamic> toJson() {
    Map <String, dynamic> json = {};
    if (receipt != null)
      json['receipt'] = receipt;
    if (price != null)
      json['price'] = price;
    if (currency != null)
      json['currency'] = currency;
    if (analyticIds != null)
      json['analytic_ids'] = analyticIds;
    if (advId != null)
      json['adv_id'] = advId;
    return json;
  }

  static List<AppleVerifyReceiptRequest> listFromJson(List<dynamic> json) {
    return json == null ? List<AppleVerifyReceiptRequest>() : json.map((value) => AppleVerifyReceiptRequest.fromJson(value)).toList();
  }

  static Map<String, AppleVerifyReceiptRequest> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, AppleVerifyReceiptRequest>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) => map[key] = AppleVerifyReceiptRequest.fromJson(value));
    }
    return map;
  }

  // maps a json object with a list of AppleVerifyReceiptRequest-objects as value to a dart map
  static Map<String, List<AppleVerifyReceiptRequest>> mapListFromJson(Map<String, dynamic> json) {
    var map = Map<String, List<AppleVerifyReceiptRequest>>();
     if (json != null && json.isNotEmpty) {
       json.forEach((String key, dynamic value) {
         map[key] = AppleVerifyReceiptRequest.listFromJson(value);
       });
     }
     return map;
  }
}
